/*
 * Copyright 2010 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

#import "SNSSubscription.h"
    
#import "../AmazonServiceResponse.h"
#import "../AmazonServiceExceptionUnmarshaller.h"
    
#import "SNSNotFoundException.h"
#import "SNSAuthorizationErrorException.h"
#import "SNSInternalErrorException.h"
#import "SNSInvalidParameterException.h"
               
/**
 * List Subscriptions By Topic Result
 */   
    
@interface SNSListSubscriptionsByTopicResponse : AmazonServiceResponse 
    
{
    NSMutableArray* subscriptions;
    NSString* nextToken;

}



/**
 * Default constructor for a new  object.  Callers should use the
 * property methods to initialize this object after creating it.
 */
-(id)init;
   
/**
 * A list of subscriptions.
 */
@property (nonatomic, retain) NSMutableArray* subscriptions;

/**
 * Token to pass along to the next ListSubscriptionsByTopic request. This
     * element is returned if there are more subscriptions to retrieve.
 */
@property (nonatomic, retain) NSString* nextToken;

/**
 * Adds a single object to subscriptions. 
 * This function will alloc and init subscriptions if not already done.
 */        
-(void)addSubscription:(SNSSubscription*)subscription;
                
/**
 * Returns a string representation of this object; useful for testing and
 * debugging.
 *
 * @return A string representation of this object.
 */
-(NSString*)description;
    

@end
    